@@ -2,9 +2,10 @@
 # -*- coding: utf-8 -*-
 
 # import classes.
+# keep this import style so you can also use the keys.Keys() etc directly.
 from ssht00ls import classes
-from ssht00ls.classes.config import version, SOURCE_PATH
-from ssht00ls.classes.config import encryption
+from ssht00ls.classes import version, SOURCE_PATH
+from ssht00ls.classes import encryption
 
 # import initialized classes.
 from ssht00ls.classes.installation import installation
