@@ -2,8 +2,12 @@
 # -*- coding: utf-8 -*-
 
 # imports.
+# keep this import style so you can also use the keys.Keys() etc directly.
 from ssht00ls.classes.config import version, SOURCE_PATH
-from ssht00ls.classes.config import encryption
+try:
+	from ssht00ls.classes.config import encryption
+except ImportError:
+	encryption = None
 
 # import classes.
 from ssht00ls.classes import utils, installation, sshd, sshfs, scp, agent, keys, connections, smart_cards, aliases, ssh, ssync
