@@ -52,9 +52,10 @@ syst3m.defaults.alias(alias=ALIAS, executable=f"{SOURCE_PATH}")
 
 # universal options.
 CLI = syst3m.env.get_boolean("CLI")
-INTERACTIVE = not cl1.arguments_present(["--non-interactive"])
+INTERACTIVE = not cl1.arguments_present(["--non-interactive"]) and not syst3m.env.get_boolean("NON_INTERACTIVE")
 CHECKS = not cl1.arguments_present(["--no-checks"])
 JSON = cl1.arguments_present(["-j", "--json"])
+print("INTERACTIVE:",INTERACTIVE)
 
 # version.
 try: version = Files.load(f"{SOURCE_PATH}/.version")
@@ -176,11 +177,11 @@ if CHECKS and not cl1.arguments_present("--reset-cache"):
 		encryption = _encryption_.Encryption(
 			config=CONFIG,
 			webserver=webserver,
-			cache=f"{syt3m.defaults.vars.home}/.{ALIAS}/.cache.enc/",
+			cache=f"{syst3m.defaults.vars.home}/.{ALIAS}/.cache.enc/",
 			interactive=INTERACTIVE,)
 
 		# generate.
-		if syst3m.env.get_boolean("START_ENCRYPTION"):
+		if INTERACTIVE:
 			if None in [CONFIG.dictionary["encryption"]["public_key"], CONFIG.dictionary["encryption"]["private_key"]]:
 				if CLI:
 					response = encryption.generate()
