@@ -16,10 +16,11 @@ class SSync(object):
 		self.utils = ssync_utils
 		self.daemons = daemons
 		if CHECKS and INTERACTIVE:
-			response = aliases.sync()
-			if not response["success"]: response.crash(json=JSON)
+			if encryption.activated:
+				response = aliases.sync()
+				if not response["success"]: response.crash(json=JSON)
 			if not cl1.argument_present("--reset-cache"):
-				_ = daemons.sync()
+				daemons.sync()
 	def mount(self, 
 		# the local path.
 		path=None, 
